@@ -7,7 +7,7 @@ import traceback
 import sys
 sys.path.insert(0, ".")
 
-for file in glob.glob("PIL/*.py"):
+for file in glob.glob("src/PIL/*.py"):
     module = os.path.basename(file)[:-3]
     try:
         exec("from PIL import " + module)
