@@ -28,7 +28,7 @@ class TestFileBmp(PillowTestCase):
     def test_invalid_file(self):
         with open("Tests/images/flower.jpg", "rb") as fp:
             self.assertRaises(SyntaxError,
-                              lambda: BmpImagePlugin.BmpImageFile(fp))
+                              BmpImagePlugin.BmpImageFile, fp)
 
     def test_save_to_bytes(self):
         output = io.BytesIO()
@@ -70,8 +70,12 @@ class TestFileBmp(PillowTestCase):
         self.assertEqual(im.size, reloaded.size)
         self.assertEqual(reloaded.format, "JPEG")
 
+    def test_load_dib(self):
+        # test for #1293, Imagegrab returning Unsupported Bitfields Format
+        im = BmpImagePlugin.DibImageFile('Tests/images/clipboard.dib')
+        target = Image.open('Tests/images/clipboard_target.png')
+        self.assert_image_equal(im, target)
+
 
 if __name__ == '__main__':
     unittest.main()
-
-# End of file
