@@ -31,7 +31,7 @@ class TestFileGif(PillowTestCase):
         invalid_file = "Tests/images/flower.jpg"
 
         self.assertRaises(SyntaxError,
-                          lambda: GifImagePlugin.GifImageFile(invalid_file))
+                          GifImagePlugin.GifImageFile, invalid_file)
 
     def test_optimize(self):
         def test_grayscale(optimize):
@@ -58,21 +58,20 @@ class TestFileGif(PillowTestCase):
         # Check for correctness after conversion back to RGB
         def check(colors, size, expected_palette_length):
             # make an image with empty colors in the start of the palette range
-            im = Image.frombytes('P', (colors,colors),
-                                 bytes(bytearray(range(256-colors,256))*colors))
-            im = im.resize((size,size))
+            im = Image.frombytes('P', (colors, colors),
+                                 bytes(bytearray(range(256-colors, 256))*colors))
+            im = im.resize((size, size))
             outfile = BytesIO()
             im.save(outfile, 'GIF')
             outfile.seek(0)
             reloaded = Image.open(outfile)
 
             # check palette length
-            palette_length = max(i+1 for i,v in enumerate(reloaded.histogram()) if v)
+            palette_length = max(i+1 for i, v in enumerate(reloaded.histogram()) if v)
             self.assertEqual(expected_palette_length, palette_length)
 
             self.assert_image_equal(im.convert('RGB'), reloaded.convert('RGB'))
 
-
         # These do optimize the palette
         check(128, 511, 128)
         check(64, 511, 64)
@@ -209,25 +208,29 @@ class TestFileGif(PillowTestCase):
             self.assertEqual(framecount, 5)
 
     def test_n_frames(self):
-        im = Image.open(TEST_GIF)
-        self.assertEqual(im.n_frames, 1)
-        self.assertFalse(im.is_animated)
+        for path, n_frames in [
+            [TEST_GIF, 1],
+            ['Tests/images/iss634.gif', 42]
+        ]:
+            # Test is_animated before n_frames
+            im = Image.open(path)
+            self.assertEqual(im.is_animated, n_frames != 1)
 
-        im = Image.open("Tests/images/iss634.gif")
-        self.assertEqual(im.n_frames, 42)
-        self.assertTrue(im.is_animated)
+            # Test is_animated after n_frames
+            im = Image.open(path)
+            self.assertEqual(im.n_frames, n_frames)
+            self.assertEqual(im.is_animated, n_frames != 1)
 
     def test_eoferror(self):
         im = Image.open(TEST_GIF)
-
         n_frames = im.n_frames
-        while True:
-            n_frames -= 1
-            try:
-                im.seek(n_frames)
-                break
-            except EOFError:
-                self.assertTrue(im.tell() < n_frames)
+
+        # Test seeking past the last frame
+        self.assertRaises(EOFError, im.seek, n_frames)
+        self.assertLess(im.tell(), n_frames)
+
+        # Test that seeking to the last frame does not raise an error
+        im.seek(n_frames-1)
 
     def test_dispose_none(self):
         img = Image.open("Tests/images/dispose_none.gif")
@@ -256,6 +259,39 @@ class TestFileGif(PillowTestCase):
         except EOFError:
             pass
 
+    def test_save_dispose(self):
+        out = self.tempfile('temp.gif')
+        im_list = [
+            Image.new('L', (100, 100), '#000'),
+            Image.new('L', (100, 100), '#111'),
+            Image.new('L', (100, 100), '#222'),
+        ]
+        for method in range(0, 4):
+            im_list[0].save(
+                out,
+                save_all=True,
+                append_images=im_list[1:],
+                disposal=method
+            )
+            img = Image.open(out)
+            for _ in range(2):
+                img.seek(img.tell() + 1)
+                self.assertEqual(img.disposal_method, method)
+
+        # check per frame disposal
+        im_list[0].save(
+            out,
+            save_all=True,
+            append_images=im_list[1:],
+            disposal=tuple(range(len(im_list)))
+            )
+
+        img = Image.open(out)
+
+        for i in range(2):
+            img.seek(img.tell() + 1)
+            self.assertEqual(img.disposal_method, i+1)
+
     def test_iss634(self):
         img = Image.open("Tests/images/iss634.gif")
         # seek to the second frame
@@ -269,9 +305,12 @@ class TestFileGif(PillowTestCase):
 
         out = self.tempfile('temp.gif')
         im = Image.new('L', (100, 100), '#000')
-        im.save(out, duration=duration)
-        reread = Image.open(out)
 
+        # Check that the argument has priority over the info settings
+        im.info['duration'] = 100
+        im.save(out, duration=duration)
+
+        reread = Image.open(out)
         self.assertEqual(reread.info['duration'], duration)
 
     def test_multiple_duration(self):
@@ -284,7 +323,7 @@ class TestFileGif(PillowTestCase):
             Image.new('L', (100, 100), '#222')
         ]
 
-        #duration as list
+        # duration as list
         im_list[0].save(
             out,
             save_all=True,
@@ -327,7 +366,7 @@ class TestFileGif(PillowTestCase):
             Image.new('L', (100, 100), '#111')
         ]
 
-        #duration as list
+        # duration as list
         im_list[0].save(
             out,
             save_all=True,
@@ -376,37 +415,49 @@ class TestFileGif(PillowTestCase):
     def test_version(self):
         out = self.tempfile('temp.gif')
 
+        def assertVersionAfterSave(im, version):
+            im.save(out)
+            reread = Image.open(out)
+            self.assertEqual(reread.info["version"], version)
+
         # Test that GIF87a is used by default
         im = Image.new('L', (100, 100), '#000')
-        im.save(out)
-        reread = Image.open(out)
-        self.assertEqual(reread.info["version"], b"GIF87a")
+        assertVersionAfterSave(im, b"GIF87a")
+
+        # Test setting the version to 89a
+        im = Image.new('L', (100, 100), '#000')
+        im.info["version"] = b"89a"
+        assertVersionAfterSave(im, b"GIF89a")
 
         # Test that adding a GIF89a feature changes the version
         im.info["transparency"] = 1
-        im.save(out)
-        reread = Image.open(out)
-        self.assertEqual(reread.info["version"], b"GIF89a")
+        assertVersionAfterSave(im, b"GIF89a")
 
         # Test that a GIF87a image is also saved in that format
         im = Image.open("Tests/images/test.colors.gif")
-        im.save(out)
-        reread = Image.open(out)
-        self.assertEqual(reread.info["version"], b"GIF87a")
+        assertVersionAfterSave(im, b"GIF87a")
 
         # Test that a GIF89a image is also saved in that format
         im.info["version"] = b"GIF89a"
-        im.save(out)
-        reread = Image.open(out)
-        self.assertEqual(reread.info["version"], b"GIF87a")
+        assertVersionAfterSave(im, b"GIF87a")
 
     def test_append_images(self):
         out = self.tempfile('temp.gif')
 
         # Test appending single frame images
         im = Image.new('RGB', (100, 100), '#f00')
-        ims = [Image.new('RGB', (100, 100), color) for color in ['#0f0', '#00f']]
-        im.save(out, save_all=True, append_images=ims)
+        ims = [Image.new('RGB', (100, 100), color) for color
+               in ['#0f0', '#00f']]
+        im.copy().save(out, save_all=True, append_images=ims)
+
+        reread = Image.open(out)
+        self.assertEqual(reread.n_frames, 3)
+
+        # Tests appending using a generator
+        def imGenerator(ims):
+            for im in ims:
+                yield im
+        im.save(out, save_all=True, append_images=imGenerator(ims))
 
         reread = Image.open(out)
         self.assertEqual(reread.n_frames, 3)
@@ -426,12 +477,10 @@ class TestFileGif(PillowTestCase):
         # that's > 128 items where the transparent color is actually
         # the top palette entry to trigger the bug.
 
-        from PIL import ImagePalette
-
-        data = bytes(bytearray(range(1,254)))
+        data = bytes(bytearray(range(1, 254)))
         palette = ImagePalette.ImagePalette("RGB", list(range(256))*3)
 
-        im = Image.new('L', (253,1))
+        im = Image.new('L', (253, 1))
         im.frombytes(data)
         im.putpalette(palette)
 
@@ -444,8 +493,8 @@ class TestFileGif(PillowTestCase):
     def test_bbox(self):
         out = self.tempfile('temp.gif')
 
-        im = Image.new('RGB', (100,100), '#fff')
-        ims = [Image.new("RGB", (100,100), '#000')]
+        im = Image.new('RGB', (100, 100), '#fff')
+        ims = [Image.new("RGB", (100, 100), '#000')]
         im.save(out, save_all=True, append_images=ims)
 
         reread = Image.open(out)
@@ -453,7 +502,7 @@ class TestFileGif(PillowTestCase):
 
     def test_palette_save_L(self):
         # generate an L mode image with a separate palette
-        
+
         im = hopper('P')
         im_l = Image.frombytes('L', im.size, im.tobytes())
         palette = bytes(bytearray(im.getpalette()))
@@ -464,7 +513,7 @@ class TestFileGif(PillowTestCase):
         reloaded = Image.open(out)
 
         self.assert_image_equal(reloaded.convert('RGB'), im.convert('RGB'))
-    
+
     def test_palette_save_P(self):
         # pass in a different palette, then construct what the image
         # would look like.
@@ -511,7 +560,7 @@ class TestFileGif(PillowTestCase):
         im = Image._wedge().resize((16, 16))
         im.putpalette(ImagePalette.ImagePalette('RGB'))
         im.info = {'background': 0}
-        
+
         passed_palette = bytes(bytearray([255-i//3 for i in range(768)]))
 
         GifImagePlugin._FORCE_OPTIMIZE = True
@@ -521,18 +570,23 @@ class TestFileGif(PillowTestCase):
 
             import pickle
             # Enable to get target values on pre-refactor version
-            #with open('Tests/images/gif_header_data.pkl', 'wb') as f:
+            # with open('Tests/images/gif_header_data.pkl', 'wb') as f:
             #    pickle.dump((h, d), f, 1)
             with open('Tests/images/gif_header_data.pkl', 'rb') as f:
                 (h_target, d_target) = pickle.load(f)
-            
+
             self.assertEqual(h, h_target)
             self.assertEqual(d, d_target)
         finally:
             GifImagePlugin._FORCE_OPTIMIZE = False
 
+    def test_lzw_bits(self):
+        # see https://github.com/python-pillow/Pillow/issues/2811
+        im = Image.open('Tests/images/issue_2811.gif')
 
-    
+        self.assertEqual(im.tile[0][3][0], 11)  # LZW bits
+        # codec error prepatch
+        im.load()
 
 
 if __name__ == '__main__':
