@@ -1,7 +1,7 @@
-from __future__ import print_function
 from helper import unittest, PillowTestCase, hopper
 
 from PIL import Image
+from PIL._util import py3
 
 import colorsys
 import itertools
@@ -58,10 +58,10 @@ class TestFormatHSV(PillowTestCase):
 
         (r, g, b) = im.split()
 
-        if bytes is str:
-            conv_func = self.str_to_float
-        else:
+        if py3:
             conv_func = self.int_to_float
+        else:
+            conv_func = self.str_to_float
 
         if hasattr(itertools, 'izip'):
             iter_helper = itertools.izip
@@ -73,11 +73,11 @@ class TestFormatHSV(PillowTestCase):
                      for (_r, _g, _b) in iter_helper(r.tobytes(), g.tobytes(),
                                                      b.tobytes())]
 
-        if str is bytes:
-            new_bytes = b''.join(chr(h)+chr(s)+chr(v) for (
+        if py3:
+            new_bytes = b''.join(bytes(chr(h)+chr(s)+chr(v), 'latin-1') for (
                 h, s, v) in converted)
         else:
-            new_bytes = b''.join(bytes(chr(h)+chr(s)+chr(v), 'latin-1') for (
+            new_bytes = b''.join(chr(h)+chr(s)+chr(v) for (
                 h, s, v) in converted)
 
         hsv = Image.frombytes(mode, r.size, new_bytes)
@@ -104,11 +104,11 @@ class TestFormatHSV(PillowTestCase):
         # im.split()[0].show()
         # comparable.split()[0].show()
 
-        self.assert_image_similar(im.split()[0], comparable.split()[0],
+        self.assert_image_similar(im.getchannel(0), comparable.getchannel(0),
                                   1, "Hue conversion is wrong")
-        self.assert_image_similar(im.split()[1], comparable.split()[1],
+        self.assert_image_similar(im.getchannel(1), comparable.getchannel(1),
                                   1, "Saturation conversion is wrong")
-        self.assert_image_similar(im.split()[2], comparable.split()[2],
+        self.assert_image_similar(im.getchannel(2), comparable.getchannel(2),
                                   1, "Value conversion is wrong")
 
         # print(im.getpixel((192, 64)))
@@ -121,11 +121,11 @@ class TestFormatHSV(PillowTestCase):
         # print(im.getpixel((192, 64)))
         # print(comparable.getpixel((192, 64)))
 
-        self.assert_image_similar(im.split()[0], comparable.split()[0],
+        self.assert_image_similar(im.getchannel(0), comparable.getchannel(0),
                                   3, "R conversion is wrong")
-        self.assert_image_similar(im.split()[1], comparable.split()[1],
+        self.assert_image_similar(im.getchannel(1), comparable.getchannel(1),
                                   3, "G conversion is wrong")
-        self.assert_image_similar(im.split()[2], comparable.split()[2],
+        self.assert_image_similar(im.getchannel(2), comparable.getchannel(2),
                                   3, "B conversion is wrong")
 
     def test_convert(self):
@@ -138,11 +138,11 @@ class TestFormatHSV(PillowTestCase):
 #        print(im.split()[0].histogram())
 #        print(comparable.split()[0].histogram())
 
-        self.assert_image_similar(im.split()[0], comparable.split()[0],
+        self.assert_image_similar(im.getchannel(0), comparable.getchannel(0),
                                   1, "Hue conversion is wrong")
-        self.assert_image_similar(im.split()[1], comparable.split()[1],
+        self.assert_image_similar(im.getchannel(1), comparable.getchannel(1),
                                   1, "Saturation conversion is wrong")
-        self.assert_image_similar(im.split()[2], comparable.split()[2],
+        self.assert_image_similar(im.getchannel(2), comparable.getchannel(2),
                                   1, "Value conversion is wrong")
 
     def test_hsv_to_rgb(self):
@@ -156,11 +156,14 @@ class TestFormatHSV(PillowTestCase):
         # print([ord(x) for x  in target.split()[1].tobytes()[:80]])
         # print([ord(x) for x  in converted.split()[1].tobytes()[:80]])
 
-        self.assert_image_similar(converted.split()[0], comparable.split()[0],
+        self.assert_image_similar(converted.getchannel(0),
+                                  comparable.getchannel(0),
                                   3, "R conversion is wrong")
-        self.assert_image_similar(converted.split()[1], comparable.split()[1],
+        self.assert_image_similar(converted.getchannel(1),
+                                  comparable.getchannel(1),
                                   3, "G conversion is wrong")
-        self.assert_image_similar(converted.split()[2], comparable.split()[2],
+        self.assert_image_similar(converted.getchannel(2),
+                                  comparable.getchannel(2),
                                   3, "B conversion is wrong")
 
 
