@@ -1,7 +1,7 @@
 from helper import unittest, PillowTestCase, hopper
 import datetime
 
-from PIL import Image
+from PIL import Image, ImageMode
 
 from io import BytesIO
 import os
@@ -43,7 +43,7 @@ class TestImageCms(PillowTestCase):
         self.assertEqual(list(map(type, v)), [str, str, str, str])
 
         # internal version number
-        self.assertRegexpMatches(ImageCms.core.littlecms_version, r"\d+\.\d+$")
+        self.assertRegex(ImageCms.core.littlecms_version, r"\d+\.\d+$")
 
         self.skip_missing()
         i = ImageCms.profileToProfile(hopper(), SRGB, SRGB)
@@ -144,20 +144,26 @@ class TestImageCms(PillowTestCase):
             'IEC 61966-2.1 Default RGB colour space - sRGB')
 
     def test_exceptions(self):
+        # Test mode mismatch
+        psRGB = ImageCms.createProfile("sRGB")
+        pLab = ImageCms.createProfile("LAB")
+        t = ImageCms.buildTransform(pLab, psRGB, "LAB", "RGB")
+        self.assertRaises(ValueError, t.apply_in_place, hopper("RGBA"))
+
         # the procedural pyCMS API uses PyCMSError for all sorts of errors
         self.assertRaises(
             ImageCms.PyCMSError,
-            lambda: ImageCms.profileToProfile(hopper(), "foo", "bar"))
+            ImageCms.profileToProfile, hopper(), "foo", "bar")
         self.assertRaises(
             ImageCms.PyCMSError,
-            lambda: ImageCms.buildTransform("foo", "bar", "RGB", "RGB"))
+            ImageCms.buildTransform, "foo", "bar", "RGB", "RGB")
         self.assertRaises(
             ImageCms.PyCMSError,
-            lambda: ImageCms.getProfileName(None))
+            ImageCms.getProfileName, None)
         self.skip_missing()
         self.assertRaises(
             ImageCms.PyCMSError,
-            lambda: ImageCms.isIntentSupported(SRGB, None, None))
+            ImageCms.isIntentSupported, SRGB, None, None)
 
     def test_display_profile(self):
         # try fetching the profile for the current display device
@@ -167,6 +173,14 @@ class TestImageCms(PillowTestCase):
         ImageCms.createProfile("LAB", 5000)
         ImageCms.createProfile("LAB", 6500)
 
+    def test_unsupported_color_space(self):
+        self.assertRaises(ImageCms.PyCMSError,
+            ImageCms.createProfile, "unsupported")
+
+    def test_invalid_color_temperature(self):
+        self.assertRaises(ImageCms.PyCMSError,
+            ImageCms.createProfile, "LAB", "invalid")
+
     def test_simple_lab(self):
         i = Image.new('RGB', (10, 10), (128, 128, 128))
 
@@ -222,7 +236,7 @@ class TestImageCms(PillowTestCase):
         self.assertTrue(img_srgb.info['icc_profile'])
 
         profile = ImageCmsProfile(BytesIO(img_srgb.info['icc_profile']))
-        self.assertTrue('sRGB' in ImageCms.getProfileDescription(profile))
+        self.assertIn('sRGB', ImageCms.getProfileDescription(profile))
 
     def test_lab_roundtrip(self):
         # check to see if we're at least internally consistent.
@@ -275,12 +289,12 @@ class TestImageCms(PillowTestCase):
         assert_truncated_tuple_equal(p.blue_colorant, ((0.14306640625, 0.06060791015625, 0.7140960693359375), (0.1558847490315394, 0.06603820639433387, 0.06060791015625)))
         assert_truncated_tuple_equal(p.blue_primary, ((0.14306641366715667, 0.06060790921083026, 0.7140960805782015), (0.15588475410450106, 0.06603820408959558, 0.06060790921083026)))
         assert_truncated_tuple_equal(p.chromatic_adaptation, (((1.04791259765625, 0.0229339599609375, -0.050201416015625), (0.02960205078125, 0.9904632568359375, -0.0170745849609375), (-0.009246826171875, 0.0150604248046875, 0.7517852783203125)), ((1.0267159024652783, 0.022470062342089134, 0.0229339599609375), (0.02951378324103937, 0.9875098886387147, 0.9904632568359375), (-0.012205438066465256, 0.01987915407854985, 0.0150604248046875))))
-        self.assertEqual(p.chromaticity, None)
+        self.assertIsNone(p.chromaticity)
         self.assertEqual(p.clut, {0: (False, False, True), 1: (False, False, True), 2: (False, False, True), 3: (False, False, True)})
         self.assertEqual(p.color_space, 'RGB')
-        self.assertEqual(p.colorant_table, None)
-        self.assertEqual(p.colorant_table_out, None)
-        self.assertEqual(p.colorimetric_intent, None)
+        self.assertIsNone(p.colorant_table)
+        self.assertIsNone(p.colorant_table_out)
+        self.assertIsNone(p.colorimetric_intent)
         self.assertEqual(p.connection_space, 'XYZ ')
         self.assertEqual(p.copyright, 'Copyright International Color Consortium, 2009')
         self.assertEqual(p.creation_date, datetime.datetime(2009, 2, 27, 21, 36, 31))
@@ -292,17 +306,17 @@ class TestImageCms(PillowTestCase):
         self.assertEqual(p.header_model, '\x00\x00\x00\x00')
         self.assertEqual(p.icc_measurement_condition, {'backing': (0.0, 0.0, 0.0), 'flare': 0.0, 'geo': 'unknown', 'observer': 1, 'illuminant_type': 'D65'})
         self.assertEqual(p.icc_version, 33554432)
-        self.assertEqual(p.icc_viewing_condition, None)
+        self.assertIsNone(p.icc_viewing_condition)
         self.assertEqual(p.intent_supported, {0: (True, True, True), 1: (True, True, True), 2: (True, True, True), 3: (True, True, True)})
-        self.assertEqual(p.is_matrix_shaper, True)
+        self.assertTrue(p.is_matrix_shaper)
         self.assertEqual(p.luminance, ((0.0, 80.0, 0.0), (0.0, 1.0, 80.0)))
-        self.assertEqual(p.manufacturer, None)
+        self.assertIsNone(p.manufacturer)
         assert_truncated_tuple_equal(p.media_black_point, ((0.012054443359375, 0.0124969482421875, 0.01031494140625), (0.34573304157549234, 0.35842450765864337, 0.0124969482421875)))
         assert_truncated_tuple_equal(p.media_white_point, ((0.964202880859375, 1.0, 0.8249053955078125), (0.3457029219802284, 0.3585375327567059, 1.0)))
         assert_truncated_tuple_equal((p.media_white_point_temperature,), (5000.722328847392,))
         self.assertEqual(p.model, 'IEC 61966-2-1 Default RGB Colour Space - sRGB')
         self.assertEqual(p.pcs, 'XYZ')
-        self.assertEqual(p.perceptual_rendering_intent_gamut, None)
+        self.assertIsNone(p.perceptual_rendering_intent_gamut)
         self.assertEqual(p.product_copyright, 'Copyright International Color Consortium, 2009')
         self.assertEqual(p.product_desc, 'sRGB IEC61966-2-1 black scaled')
         self.assertEqual(p.product_description, 'sRGB IEC61966-2-1 black scaled')
@@ -313,9 +327,9 @@ class TestImageCms(PillowTestCase):
         assert_truncated_tuple_equal(p.red_colorant, ((0.436065673828125, 0.2224884033203125, 0.013916015625), (0.6484536316398539, 0.3308524880306778, 0.2224884033203125)))
         assert_truncated_tuple_equal(p.red_primary, ((0.43606566581047446, 0.22248840582960838, 0.013916015621759925), (0.6484536250319214, 0.3308524944738204, 0.22248840582960838)))
         self.assertEqual(p.rendering_intent, 0)
-        self.assertEqual(p.saturation_rendering_intent_gamut, None)
-        self.assertEqual(p.screening_description, None)
-        self.assertEqual(p.target, None)
+        self.assertIsNone(p.saturation_rendering_intent_gamut)
+        self.assertIsNone(p.screening_description)
+        self.assertIsNone(p.target)
         self.assertEqual(p.technology, 'CRT ')
         self.assertEqual(p.version, 2.0)
         self.assertEqual(p.viewing_condition, 'Reference Viewing Condition in IEC 61966-2-1')
@@ -332,6 +346,97 @@ class TestImageCms(PillowTestCase):
         with self.assertRaises(TypeError):
             ImageCms.ImageCmsProfile(1).tobytes()
 
+    def assert_aux_channel_preserved(self, mode, transform_in_place, preserved_channel):
+        def create_test_image():
+            # set up test image with something interesting in the tested aux
+            # channel.
+            nine_grid_deltas = [
+                (-1, -1), (-1, 0), (-1, 1),
+                ( 0, -1), ( 0, 0), ( 0, 1),
+                ( 1, -1), ( 1, 0), ( 1, 1),
+            ]
+            chans = []
+            bands = ImageMode.getmode(mode).bands
+            for band_ndx in range(len(bands)):
+                channel_type = 'L'  # 8-bit unorm
+                channel_pattern = hopper(channel_type)
+
+                # paste pattern with varying offsets to avoid correlation
+                # potentially hiding some bugs (like channels getting mixed).
+                paste_offset = (
+                    int(band_ndx / float(len(bands)) * channel_pattern.size[0]),
+                    int(band_ndx / float(len(bands) * 2) * channel_pattern.size[1])
+                )
+                channel_data = Image.new(channel_type, channel_pattern.size)
+                for delta in nine_grid_deltas:
+                    channel_data.paste(channel_pattern, tuple(paste_offset[c] + delta[c]*channel_pattern.size[c] for c in range(2)))
+                chans.append(channel_data)
+            return Image.merge(mode, chans)
+
+        source_image = create_test_image()
+        source_image_aux = source_image.getchannel(preserved_channel)
+
+        # create some transform, it doesn't matter which one
+        source_profile = ImageCms.createProfile("sRGB")
+        destination_profile = ImageCms.createProfile("sRGB")
+        t = ImageCms.buildTransform(source_profile, destination_profile, inMode=mode, outMode=mode)
+
+        # apply transform
+        if transform_in_place:
+            ImageCms.applyTransform(source_image, t, inPlace=True)
+            result_image = source_image
+        else:
+            result_image = ImageCms.applyTransform(source_image, t, inPlace=False)
+        result_image_aux = result_image.getchannel(preserved_channel)
+
+        self.assert_image_equal(source_image_aux, result_image_aux)
+
+    def test_preserve_auxiliary_channels_rgba(self):
+        self.assert_aux_channel_preserved(mode='RGBA', transform_in_place=False, preserved_channel='A')
+
+    def test_preserve_auxiliary_channels_rgba_in_place(self):
+        self.assert_aux_channel_preserved(mode='RGBA', transform_in_place=True, preserved_channel='A')
+
+    def test_preserve_auxiliary_channels_rgbx(self):
+        self.assert_aux_channel_preserved(mode='RGBX', transform_in_place=False, preserved_channel='X')
+
+    def test_preserve_auxiliary_channels_rgbx_in_place(self):
+        self.assert_aux_channel_preserved(mode='RGBX', transform_in_place=True, preserved_channel='X')
+
+    def test_auxiliary_channels_isolated(self):
+        # test data in aux channels does not affect non-aux channels
+        aux_channel_formats = [
+            # format, profile, color-only format, source test image
+            ('RGBA', 'sRGB', 'RGB', hopper('RGBA')),
+            ('RGBX', 'sRGB', 'RGB', hopper('RGBX')),
+            ('LAB', 'LAB', 'LAB', Image.open('Tests/images/hopper.Lab.tif')),
+        ]
+        for src_format in aux_channel_formats:
+            for dst_format in aux_channel_formats:
+                for transform_in_place in [True, False]:
+                    # inplace only if format doesn't change
+                    if transform_in_place and src_format[0] != dst_format[0]:
+                        continue
+
+                    # convert with and without AUX data, test colors are equal
+                    source_profile = ImageCms.createProfile(src_format[1])
+                    destination_profile = ImageCms.createProfile(dst_format[1])
+                    source_image = src_format[3]
+                    test_transform = ImageCms.buildTransform(source_profile, destination_profile, inMode=src_format[0], outMode=dst_format[0])
+
+                    # test conversion from aux-ful source
+                    if transform_in_place:
+                        test_image = source_image.copy()
+                        ImageCms.applyTransform(test_image, test_transform, inPlace=True)
+                    else:
+                        test_image = ImageCms.applyTransform(source_image, test_transform, inPlace=False)
+
+                    # reference conversion from aux-less source
+                    reference_transform = ImageCms.buildTransform(source_profile, destination_profile, inMode=src_format[2], outMode=dst_format[2])
+                    reference_image = ImageCms.applyTransform(source_image.convert(src_format[2]), reference_transform)
+
+                    self.assert_image_equal(test_image.convert(dst_format[2]), reference_image)
+
 
 if __name__ == '__main__':
     unittest.main()
