@@ -42,7 +42,7 @@ class SimplePatcher(object):
             delattr(self._parent_obj, self._attr_name)
 
 
-@unittest.skipUnless(HAS_FREETYPE, "ImageFont not Available")
+@unittest.skipUnless(HAS_FREETYPE, "ImageFont not available")
 class TestImageFont(PillowTestCase):
     LAYOUT_ENGINE = ImageFont.LAYOUT_BASIC
 
@@ -75,8 +75,7 @@ class TestImageFont(PillowTestCase):
                                   layout_engine=self.LAYOUT_ENGINE)
 
     def test_sanity(self):
-        self.assertRegexpMatches(
-            ImageFont.core.freetype2_version, r"\d+\.\d+\.\d+$")
+        self.assertRegex(ImageFont.core.freetype2_version, r"\d+\.\d+\.\d+$")
 
     def test_font_properties(self):
         ttf = self.get_font()
@@ -232,6 +231,11 @@ class TestImageFont(PillowTestCase):
         self.assertEqual(draw.textsize(TEST_TEXT, font=ttf),
                          draw.multiline_textsize(TEST_TEXT, font=ttf))
 
+        # Test that multiline_textsize corresponds to ImageFont.textsize()
+        # for single line text
+        self.assertEqual(ttf.getsize('A'),
+                         draw.multiline_textsize('A', font=ttf))
+
         # Test that textsize() can pass on additional arguments
         # to multiline_textsize()
         draw.textsize(TEST_TEXT, font=ttf, spacing=4)
@@ -510,6 +514,12 @@ class TestImageFont(PillowTestCase):
         self.assertEqual(t.getsize('M'), self.metrics['getters'])
         self.assertEqual(t.getsize('y'), (12, 20))
         self.assertEqual(t.getsize('a'), (12, 16))
+        self.assertEqual(t.getsize_multiline('A'), (12, 16))
+        self.assertEqual(t.getsize_multiline('AB'), (24, 16))
+        self.assertEqual(t.getsize_multiline('a'), (12, 16))
+        self.assertEqual(t.getsize_multiline('ABC\n'), (36, 36))
+        self.assertEqual(t.getsize_multiline('ABC\nA'), (36, 36))
+        self.assertEqual(t.getsize_multiline('ABC\nAaaa'), (48, 36))
 
 
 @unittest.skipUnless(HAS_RAQM, "Raqm not Available")
