@@ -6,7 +6,7 @@ pacman -S --noconfirm mingw32/mingw-w64-i686-python3-pip \
 	   mingw32/mingw-w64-i686-python2-setuptools \
 	   mingw-w64-i686-libjpeg-turbo
 
-C:/msys64/mingw32/bin/python3 -m pip install --upgrade pip
+C:/msys64/mingw32/bin/python3 -m pip install --upgrade --no-cache-dir pip
 
-/mingw32/bin/pip install pytest pytest-cov olefile
-/mingw32/bin/pip3 install pytest pytest-cov olefile
+/mingw32/bin/pip install --no-cache-dir pytest pytest-cov olefile
+/mingw32/bin/pip3 install --no-cache-dir pytest pytest-cov olefile
